@@ -3,6 +3,7 @@
 use std::cell::{Cell, RefCell};
 use std::cmp::PartialEq;
 use std::fmt;
+use std::iter::FromIterator;
 use std::iter::IntoIterator;
 use std::rc::Rc;
 
@@ -337,5 +338,15 @@ impl<T: Clone> IntoIterator for ArrayList<T> {
     }
 }
 
+impl<T: Clone + PartialEq + std::fmt::Debug> FromIterator<T> for ArrayList<T> {
+    fn from_iter<I: IntoIterator<Item = T>>(iter: I) -> Self {
+        let ns = arraylist![];
+        for val in iter {
+            ns.push(val);
+        }
+        ns
+    }
+}
+
 #[cfg(test)]
 mod tests;
